// Assert functions return if executed without errors

#define _GNU_SOURCE

#include "libc.h"

#include <stdarg.h>
#include <stdlib.h>
#include <string.h>
#include <bestiola/assert.h>

char *assert_aprintf(const char *fmt, ...) {
	char *strp;
	va_list ap;
	va_start(ap, fmt);
	int ret = vasprintf(&strp, fmt, ap);
	va_end(ap);
	if (ret == -1)
		assert_error_handler();
	return strp;
}

void assert_fclose(FILE *fp) {
	if (fclose(fp))
		assert_error_handler();
}

FILE *assert_fdopen(int fd, const char *mode) {
	FILE *stream = fdopen(fd, mode);
	if (!stream)
		assert_error_handler();
	return stream;
}

FILE *assert_fopen(const char *path, const char *mode) {
	FILE *stream = fopen(path, mode);
	if (!stream)
		assert_error_handler();
	return stream;
}

void assert_fputs(const char *s, FILE *stream) {
	if (fputs(s, stream) == EOF)
		assert_error_handler();
}

void *assert_malloc(size_t size) {
	void *ptr = malloc(size);
	if (!ptr && size)
		assert_error_handler();
	return ptr;
}

void assert_putc(int c, FILE *stream) {
	if (putc(c, stream) == EOF)
		assert_error_handler();
}

char *assert_strdup(const char *s) {
	char *sdup = strdup(s);
	if (!sdup)
		assert_error_handler();
	return sdup;
}
